@@ -65,9 +65,11 @@ class tmux(object):
             stdout = self.process.stdout.read()
             stderr = self.process.stderr.read()
         except Exception as e:
-            logger.error('Exception for %s: \n%s' % (
-                subprocess.list2cmdline(cmd),
-                e.message)
+            logger.error(
+                'Exception for %s: \n%s' % (
+                    subprocess.list2cmdline(cmd),
+                    e
+                )
             )
         self.stdout = stdout.decode().split('\n')
         self.stdout = list(filter(None, self.stdout))  # filter empty values
@@ -148,10 +150,10 @@ class TmuxRelationalObject(object):
         .. _underscore.js: http://underscorejs.org/
 
         """
-        return self.where(attrs, True)
+        return self.where(attrs)[0] or None
 
     def where(self, attrs, first=False):
-        """Return objects matching child objects properties>
+        """Return objects matching child objects properties.
 
         Based on `.where()`_ from `underscore.js`_.
 
